package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@(!`0````````````,`MP`!````P"````````!``````````'"A````
M`````````$``.``'`$``%@`5``8````%````0`````````!``````````$``
M````````B`$```````"(`0````````@``````````P````0```#(`0``````
M`,@!````````R`$````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````,B-````````R(T`````````
M``$```````$````&````:)L```````!HFP$``````&B;`0``````2`4`````
M``"H%0```````````0```````@````8```"`FP```````(";`0``````@)L!
M``````#@`0```````.`!````````"`````````!1Y71D!@``````````````
M```````````````````````````````````````````0`````````%+E=&0$
M````:)L```````!HFP$``````&B;`0``````F`0```````"8!`````````$`
M````````+VQI8B]L9"UM=7-L+6%A<F-H-C0N<V\N,0`````````1````4```
M``0````(````(0````7`!(`H`!`!@(9`@((A``0)``2)B(`80;H$`@A0````
M40```%4```!:````6P```&$```!B````8P````````!E``````````````!F
M````9P```&D```````````````&O-.AJ?YI\ZM/O#L[>1RUOQ=\?+L6;MKB-
M\0[49-1\=E0\E"'_Y`[9<5@<^J%L8,+E/RRR`8MOXD?&`5COEWF[XY)\5<,\
MTF>OS&:(!W#30T75[#-BV^U_J9R;X*<""K_:5QNCX/M)````````````````
M```````````````````````````#``<`J!H````````````````````````#
M``\`>)L!``````````````````P````2`````````````````````````.<!
M```2`````````````````````````!0````1````````````````````````
M``T"```1`````````````````````````(D!```2````````````````````
M`````!L````2`````````````````````````,8!```2````````````````
M`````````",````2`````````````````````````"H````2````````````
M`````````````!H"```2`````````````````````````-(!```2````````
M`````````````````#,````@`````````````````````````&0#```A````
M`````````````````````$L````2`````````````````````````%$````2
M`````````````````````````%@````2`````````````````````````"H#
M```2`````````````````````````!L#```2````````````````````````
M`)\"```2`````````````````````````%\````2````````````````````
M`````$`"```2`````````````````````````&8````2````````````````
M`````````-0"```2`````````````````````````&T````2````````````
M`````````````'4````@`````````````````````````(D````2````````
M`````````````````+T"```2`````````````````````````)$````2````
M`````````````````````)<````2`````````````````````````*`````@
M`````````````````````````!0#```2`````````````````````````+P`
M```2`````````````````````````,$````2````````````````````````
M`"L"```1`````````````````````````-L"```2````````````````````
M`````&T"```2`````````````````````````#H#```2````````````````
M`````````%\"```2`````````````````````````.`#```2````````````
M`````````````.8"```1`````````````````````````&,#```1````````
M`````````````````)$"```2`````````````````````````%`#```2````
M`````````````````````&4#```1`````````````````````````,@````2
M`````````````````````````$@#```2`````````````````````````-$`
M```1`````````````````````````)<!```2````````````````````````
M`.,````B`````````````````````````/(````@````````````````````
M``````@!```2``````````````````````````P#```2````````````````
M`````````'T"```2``````````````````````````T!```2````````````
M`````````````!,!```@`````````````````````````,@"```2````````
M`````````````````"T!```2`````````````````````````+<!```2````
M`````````````````````#(!```2`````````````````````````*T"```2
M`````````````````````````*8!```2`````````````````````````#@!
M```2`````````````````````````$D!```2````````````````````````
M`#L"```2`````````````````````````)(````2````````````````````
M`````$P"```2`````````````````````````(8"```2````````````````
M`````````$$#```2`````````````````````````$\!```2````````````
M`````````````#(#```2`````````````````````````&,!```2````````
M`````````````````#8"```2`````````````````````````/4!```2````
M`````````````````````&H!```2`````````````````````````'$!```2
M`````````````````````````&(#```A`````````````````````````((!
M```2`````````````````````````(\#```0`!,`$+$!````````````````
M`%T#```2``D`P!X``````````@````````<"```2``H`I$T````````$````
M`````"($```2``D`Y$`````````0"0```````)@$```2``D`/$T```````!H
M`````````/\#```2``D`?#H````````$`````````#$$```2``<`J!H`````
M```$`````````$4$```2``D`]$D```````!(`P```````(`#```0`!,`L*`!
M`````````````````(L$```2``D`@#H```````#H`0```````'0#```0`!,`
ML*`!`````````````````!`$```2``D`S#\````````8`0```````"\$```2
M``D`P#@````````X`````````#<$```2``D`2#\```````!<`````````&4$
M```2``D`:#P````````@`````````)H#```0`!,`$+$!````````````````
M`*(#```0`!,`$+$!`````````````````,4#```2``D`W"`````````P````
M`````'($```2``D`B#P````````$`0```````%L$```1`!(`J*`!```````(
M`````````&T#```0`!(`L*`!`````````````````'D#```2``D`P"``````
M`````````````,X#```2``D`I#\````````H`````````.D#```2``D`3#D`
M```````P`0```````(X#```0`!,`$+$!`````````````````'X$```2``D`
MC#T```````"\`0````````!L:6)P97)L+G-O`&]P96YD:7(`<W1D97)R`')E
M86QL;V,`86-C97-S`'-N<')I;G1F`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O
M`&QS965K`&=E='!I9`!S=')C;7``;65M<V5T`'5N;&EN:P!M96UM;W9E`%]*
M=E]296=I<W1E<D-L87-S97,`<W1R;F-M<`!L<W1A=`!C;&]S961I<@!?251-
M7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S='(`<F5A9&QI;FL`
M7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F
M<F%M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!R96%D`')M9&ER`%]?97)R;F]?;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G
M971S<&5C:69I8P!M96UC<'D`<W1R;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T
M=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?
M;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%]F:6YI
M`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R
M;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO
M<GE?=W)A<`!L:6)C+FUU<VPM86%R8V@V-"YS;RXQ`&9P<FEN=&8`<W1R9'5P
M`'!T:')E861?871F;W)K`')E861D:7(`<W!R:6YT9@!S=')C:'(`<W1R=&]K
M`'-T<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV:7)O;@!?961A=&$`
M7U]B<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?
M`%]E;F0`+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4`7W-T87)T7V,`
M9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK
M=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?
M:6YI=%]E;G8`<&%R7V9I;F1P<F]G`'!A<E]C;&5A;G5P``````!HFP$`````
M``,$````````X"$```````!PFP$```````,$````````>"$```````!PGP$`
M``````,$````````P!X```````"(GP$```````,$````````I$T```````"H
MGP$```````,$````````J!H`````````H`$```````,$`````````*`!````
M```0H`$```````,$````````JU`````````8H`$```````,$````````H5``
M```````@H`$```````,$````````KE`````````HH`$```````,$````````
MI%`````````PH`$```````,$````````J5`````````XH`$```````,$````
M````NU````````!(H`$```````,$````````G%````````!0H`$```````,$
M````````Y4T```````!@H`$```````,$````````VDX```````!HH`$`````
M``,$````````TTX```````!PH`$```````,$````````D%````````!XH`$`
M``````,$````````\$X```````"`H`$```````,$````````F%````````"0
MH`$```````,$````````@E````````"8H`$```````,$````````AU``````
M``"HH`$```````,$````````QE````````!XGP$```````$$```%````````
M``````"`GP$```````$$```&``````````````"0GP$```````$$```.````
M``````````"8GP$```````$$```;``````````````"@GP$```````$$```@
M``````````````"PGP$```````$$```D``````````````"XGP$```````$$
M```J``````````````#`GP$```````$$```N``````````````#(GP$`````
M``$$```Q``````````````#0GP$```````$$```S``````````````#8GP$`
M``````$$```T``````````````#@GP$```````$$```Y``````````````#H
MGP$```````$$```^``````````````#PGP$```````$$```_````````````
M``#XGP$```````$$``!$``````````````!XG0$```````($```#````````
M``````"`G0$```````($```$``````````````"(G0$```````($```'````
M``````````"0G0$```````($```(``````````````"8G0$```````($```)
M``````````````"@G0$```````($```*``````````````"HG0$```````($
M```+``````````````"PG0$```````($```,``````````````"XG0$`````
M``($```-``````````````#`G0$```````($```.``````````````#(G0$`
M``````($```0``````````````#0G0$```````($```1``````````````#8
MG0$```````($```2``````````````#@G0$```````($```3````````````
M``#HG0$```````($```4``````````````#PG0$```````($```5````````
M``````#XG0$```````($```6````````````````G@$```````($```7````
M```````````(G@$```````($```8```````````````0G@$```````($```9
M```````````````8G@$```````($```:```````````````@G@$```````($
M```<```````````````HG@$```````($```=```````````````PG@$`````
M``($```>```````````````XG@$```````($```?``````````````!`G@$`
M``````($```A``````````````!(G@$```````($```B``````````````!0
MG@$```````($```C``````````````!8G@$```````($```E````````````
M``!@G@$```````($```F``````````````!HG@$```````($```G````````
M``````!PG@$```````($```H``````````````!XG@$```````($```I````
M``````````"`G@$```````($```L``````````````"(G@$```````($```M
M``````````````"0G@$```````($```O``````````````"8G@$```````($
M```P``````````````"@G@$```````($```R``````````````"HG@$`````
M``($```S``````````````"PG@$```````($```T``````````````"XG@$`
M``````($```U``````````````#`G@$```````($```V``````````````#(
MG@$```````($```W``````````````#0G@$```````($```X````````````
M``#8G@$```````($```Z``````````````#@G@$```````($```[````````
M``````#HG@$```````($```\``````````````#PG@$```````($```]````
M``````````#XG@$```````($``!`````````````````GP$```````($``!!
M```````````````(GP$```````($``!"```````````````0GP$```````($
M``!#```````````````8GP$```````($``!%```````````````@GP$`````
M``($``!&```````````````HGP$```````($``!'```````````````PGP$`
M``````($``!(```````````````XGP$```````($``!)``````````````!`
MGP$```````($``!*``````````````!(GP$```````($``!+````````````
M``!0GP$```````($``!,``````````````!8GP$```````($``!-````````
M``````!@GP$```````($``!/``````````````#]>[^I_0,`D?U[P:C``U_6
M``````````#P>[^IT```D!&Z1OD0PC61(`(?UA\@`]4?(`/5'R`#U=```)`1
MOD;Y$.(UD2`"'];0``"0$<)&^1`"-I$@`A_6T```D!'&1OD0(C:1(`(?UM``
M`)`1RD;Y$$(VD2`"'];0``"0$<Y&^1!B-I$@`A_6T```D!'21OD0@C:1(`(?
MUM```)`1UD;Y$*(VD2`"'];0``"0$=I&^1#"-I$@`A_6T```D!'>1OD0XC:1
M(`(?UM```)`1XD;Y$`(WD2`"'];0``"0$>9&^1`B-Y$@`A_6T```D!'J1OD0
M0C>1(`(?UM```)`1[D;Y$&(WD2`"'];0``"0$?)&^1""-Y$@`A_6T```D!'V
M1OD0HC>1(`(?UM```)`1^D;Y$,(WD2`"'];0``"0$?Y&^1#B-Y$@`A_6T```
MD!$"1_D0`CB1(`(?UM```)`1!D?Y$"(XD2`"'];0``"0$0I'^1!".)$@`A_6
MT```D!$.1_D08CB1(`(?UM```)`1$D?Y$((XD2`"'];0``"0$19'^1"B.)$@
M`A_6T```D!$:1_D0PCB1(`(?UM```)`1'D?Y$.(XD2`"'];0``"0$2)'^1`"
M.9$@`A_6T```D!$F1_D0(CF1(`(?UM```)`1*D?Y$$(YD2`"'];0``"0$2Y'
M^1!B.9$@`A_6T```D!$R1_D0@CF1(`(?UM```)`1-D?Y$*(YD2`"'];0``"0
M$3I'^1#".9$@`A_6T```D!$^1_D0XCF1(`(?UM```)`10D?Y$`(ZD2`"'];0
M``"0$49'^1`B.I$@`A_6T```D!%*1_D00CJ1(`(?UM```)`13D?Y$&(ZD2`"
M'];0``"0$5)'^1"".I$@`A_6T```D!%61_D0HCJ1(`(?UM```)`16D?Y$,(Z
MD2`"'];0``"0$5Y'^1#B.I$@`A_6T```D!%B1_D0`CN1(`(?UM```)`19D?Y
M$"([D2`"'];0``"0$6I'^1!".Y$@`A_6T```D!%N1_D08CN1(`(?UM```)`1
M<D?Y$(([D2`"'];0``"0$79'^1"B.Y$@`A_6T```D!%Z1_D0PCN1(`(?UM``
M`)`1?D?Y$.([D2`"'];0``"0$8)'^1`"/)$@`A_6T```D!&&1_D0(CR1(`(?
MUM```)`1BD?Y$$(\D2`"'];0``"0$8Y'^1!B/)$@`A_6T```D!&21_D0@CR1
M(`(?UM```)`1ED?Y$*(\D2`"'];0``"0$9I'^1#"/)$@`A_6T```D!&>1_D0
MXCR1(`(?UM```)`1HD?Y$`(]D2`"'];0``"0$:9'^1`B/9$@`A_6T```D!&J
M1_D00CV1(`(?UM```)`1KD?Y$&(]D2`"'];0``"0$;)'^1""/9$@`A_6_7N[
MJ?T#`)'S4P&ITP``T/43`/G4``"0H$\`N:!#`9&A(P#YH0,!D0*,'OCB`P"J
MH#,!D8___Y?"``"0P```D$+\1_D`^$?YX0,"JBW__Y?```"0`,!'^0``0#F`
M`0`U8/__EV*B!Y%``!+X8```M2``@%*+__^7HO__EX#:1_D``$"YO___EQ_4
M(SF4VD?Y@`)`N;O__Y<!R%,Y(0`?,@'($SF``D"YMO__EP'(4SDA```R`<@3
M.0$`_)*@3T"Y`!0`$0!\0),?``'KR0``5,$``)````#P`*PXD2'<1_GP_O^7
M`/!]TW[__Y>E(T#Y8J('D>0`@))``!'XH0!`^0$``/DA``"0(?`!D0$$`/G!
M``"P(51`^0$(`/DA``"0(?P!D0$,`/F!`(!208`0N`$`@-*B3T"Y(00`D5\`
M`6ML!0!401``$76B!Y'C`P"J0@P`$8',(8L$`(#2'V@A^`$``+"@`E+X(>`C
MD07__Y?T`P`J@```-:`"4OA1__^7]`,`*G6B!Y&@`E+X*?__EP```-``Y#F1
M]00`E&`!`+6@@E'XH```M0```-``N#B1[P0`E*""$?A@H@>1`(!1^$```+0N
M"P"4<Z('D6`"4OAX__^7F_[_E_430/G@`Q0J\U-!J?U[Q:C``U_6(Q``$:9X
M8?B#S".+!F@C^,___Q<=`(#2'@"`TN`#`)&A``#P(0`ND1_L?)(!```4_7N_
MJ:0``/"C``#P`B``D?T#`)$!`$"YH```\(3$1_D%`(#28]1'^0"X1_G^_O^7
MP0``D,```)`AP`*1`,`"D2$<`)$A``#+/S@`\:D``%2A``#P(=!'^4$``+0@
M`!_6P`-?UL```)#!``"0`,`"D2'``I$A``#+0@"`TB'\0Y,A#,*:H0``M*(`
M`/!"\$?Y0@``M$``'];``U_6P```D`'`0CGA`@`U_7N^J?T#`)'S"P#Y\P,`
MJJ```/``Z$?Y@```M,```)```$#YYO[_E]C__Y>@``#P`,A'^8```+0@``#0
M`!`WD6O^_Y<@`(!28,(".?,+0/G]>\*HP`-?UL`#7]:@``#P_7N_J?T#`)$`
M[$?YP```M,$``)`@``#0(>`"D0`0-Y'3_O^7H```\`#@+9$!`$#YH0``M*$`
M`/`AS$?Y00``M"``/];]>\&HQ?__%_]#"M&G``#P".``D0,`@-+]>[^I_0,`
MD>'D1_DB`$#YHD\!^0(`@-*A8P"1)B``D05I8_@":6.X8R``D7\``?%"",!:
MPH`?^*+\8--$'&C30MQXTT(<<)*"``*JI/QHTX0<>)*%X$6J0@`%JL($`?@!
M_O]4)``(D2,@0/DA(`"1(C!`^26`7_A"``/*(P1`^6,`!<I"``/*0_Q?TV($
M`JI"?$"2(CP`^9\``>MA_O]4"2!`J0HL0:D``6>>80%GG@7]0M-"`6>>(OU;
MTZ5X"*JC#T#YL'Q`DD(4":H,$$#Y+_U"T^]Y":I`'&$N`0)GGN]]0)(!`&:>
M(`%GGB`<8BXB0"*+(3./TD%0J_)C``&+0@`#BZ,30/D$`&:>0@`,BTY\0))C
M``&+0@`/BH0`"XN#``.+Q/U;TX04#JID0"2+`P(NBF,``JJB%T#YAGQ`DF,`
M"HM"``&+Y0$FBF,``HO"_4+3S?Q;TT)X#JI"?$"2K14&JHX``HK$_$+3;4`M
MBZ4`#JJ&>`:JHWU`DL9\0))$`".*K0$&BJ4`$(N$``VJ</Q;TX0`#XNN/T.I
M$!8#JLX!`8OO`0&+I0`.BV[\0M.$``^+L$`PB\-Y`ZH%?D"28WQ`DLX`)8H0
M`@.*S@$0JJW\6]/"`0*+KB-`^:T5!:K.`0&+C4`MBT(`#HND?4"2KOQ"TV\`
M)(K%>06JD/Q;TX[\0M.E?$"2$!8$JL1Y!*J$?$"2K0$%BE!`,(OO`0VJ`GY`
MDA`"!(JN`"**Y@$&B\X!$*K#`0.+3?Q;TZ^[1*FM%0*J[P$!B\X!`8O&``^+
M8P`.BT[\0M/-0"V+IGU`DL)Y`JJ/`":*0GQ`DJT!`HK0_%O3SOQ"T^\!#:H0
M%@:JQGD&JL9\0)+E`06+<$`PBP-^0)(0`@:*3@`CBLX!$*K$`02+;?Q;TZ^[
M1:FM%0.J[P$!B\X!`8NE``^+A``.BV[\0M.M0"V+I7U`DL-Y`ZK/`"6*8WQ`
MDJT!`XJP_%O3KOQ"T^\!#:H0%@6JQ7D%JJ5\0)+B`0*+D$`PBP1^0)(0`@6*
M;@`DBLX!$*K&`0:+C?Q;TZ^[1JFM%02J[P$!B\X!`8M"``^+Q@`.BX[\0M--
M0"V+HGU`DL1Y!*JO`"**A'Q`DJT!!(I0_%O33OQ"T^\!#:H0%@*JPGD"JD)\
M0)+C`0.+T$`PBP9^0)(0`@**C@`FBLX!$*K%`06+S?Q;TZ^[1ZFM%0:J[P$!
MB\X!`8MC``^+I0`.B\[\0M-M0"V+HWU`DL9Y!JK&?$"23P`CBJT!!HIP_%O3
M[P$-JN0!!(L0%@.JK[=(J;!`,(L%?D"2[P$!BZT!`8NN_%O3A``/B\X5!:J1
M0"Z+9/Q"TS)^0)+.`"6*@W@#JF-\0)(0`@.*;P`RBLX!$*I0_EO3P@$"BT(`
M#8L0%A*J4$`PBZ+\0M,$?D"217@%JJ5\0)(N`@6*K0`DBN\!#JJ._%O3[P$&
MBZ9/0/G.%02JQ@`!B^\!!HM&_D+3[T$NBX[\0M/&>!*JXGU`DL1Y!*K&?$"2
MA'Q`DA`"!HK.`"**[P$$BJT!$*K.`0^JHP$#B\4!!8NM.TJIK0$!B\X!`8MC
M``V+3?Q;TZ4`#HNM%0*J;4`MBZ-]0))N_%O3SA4#JJ5`+HM._$+3L'Q`DL)Y
M`JJ.`".*3WQ`DJT!#XK-`0VJK0$&BZ9;0/G!``&+!OY;TZ$!`8O&%!"J,D`F
MBV'\0M--?D"2(W@#JB%TG=)"``/*(=NM\D(`!4JE_5O30@`$BZ1?0/FE%`VJ
MA``!BT(`!(L$_D+3A'@0JD)`)8MF``3*I6-`^5%\0)+&`!)*I0`!B\8`#XO&
M``6+I?U"TR[^6].M>`VJSA41JH4`#<JE``)*(OY"T\9`+HO0?$"2I4`CBZ-G
M0/E">!&J8P`!BZ4``XL#_EO38Q00JJ-`(XNE`0+*;WQ`DJ8`!DJE:T#YQ$`D
MBP;^0M/N_5O3I0`!BX0`!8O&>!"JSA4/JD4`!LJC``-*I6]`^81`+HN1?$"2
MI0`!BV-`+8MC``6+Y?U"TRW^6].E>`^JK141JF-`+8O-``7*I`$$2G!\0)*"
M0"*+I'-`^0W^6].$``&+0@`$BR3^0M.M%1"JA'@1JD)`+8NM``3*HP$#2DY\
M0))F0":+HW=`^<W]6]-C``&+Q@`#BP/^0M.M%0ZJ8W@0JL9`+8N-``/*H@$"
M2M%\0))%0"6+HGM`^2W^6]-"``&+I0`"B\+]0M.M%1&J0G@.JJ5`+8MM``+*
MI@$&2J]\0)+$0"2+IG]`^>W]6]/&``&+A``&BR;^0M.M%0^JQG@1JH1`+8M-
M``;*I0$%2HY\0)*C0".+I8-`^<W]6].E``&+8P`%B^7]0M.M%0ZJI7@/JF-`
M+8O-``7*I`$$2G!\0)*"0"*+I(=`^0W^6].$``&+0@`$B\3]0M.M%1"JA'@.
MJD)`+8NM``3*HP$#2D]\0))F0":+HXM`^>W]6]-C``&+Q@`#BP/^0M.M%0^J
M8W@0JL9`+8N-``/*H@$"2LY\0))%0"6+HH]`^<W]6]-"``&+I0`"B^+]0M.M
M%0ZJ0G@/JJ5`+8MM``+*I@$&2K%\0)+$0"2+II-`^2W^6]/&``&+A``&B\;]
M0M.M%1&JQG@.JH1`+8M-``;*I0$%2I!\0)*C0".+I9=`^0W^6].E``&+8P`%
MBR7^0M.M%1"JI7@1JF-`+8O-``7*I`$$2F]\0)*"0"*+I)M`^>[]6].$``&+
M0@`$BP3^0M/.%0^JA'@0JJT`!,I.0"Z+PGU`DJ,!`TIF0":+HY]`^4W\6]-C
M``&+Q@`#BZT5`JKC_4+3S4`MBV]X#ZJF?4"2@P`/RFX`#DJCHT#YQ4$EB\[\
M6]-C``&+I0`#B\X5!JI#_$+3KD`NBV)X`JK%?4"2XP$"RFT`#4JCIT#YI$$D
MBZW\6]-C``&+A``#BZT5!:K#_$+3C4`MBV9X!JJD?4"20P`&RF,`#DJNJT#Y
MP0$!BX[\6]-C0"^+80`!B\X5!*HQ0"Z+H?Q"TR-^0)(E>`6JSP`%JL$`!8KM
M`0V*K0$!*H&;E])AX['RHD$BBZVO0/FM`0&+0@`-BVW\6].M%0.J4$`MBXW\
M0M,"?D"2I'D$JJX`!*JM``2*S@$1BLX!#2IM_$+3QD$FBZZS0/FC>0.JS@$!
MBXT``ZK&``Z+3OQ;TZT!$(K.%0*JST`NBXX``XJM`0XJYGU`DJ5!)8NMMT#Y
MK0$!BZ4`#8O-_%O3K14&JK!`+8M-_$+3!7Y`DJ)Y`JIN``*J;0`"BLX!#XK.
M`0TJS?Q"T\1!)(NNNT#YIGD&JLX!`8M-``:JA``.BZ[\6].M`1"*SA4%JH]`
M+HM.``:*K0$.*N1]0)*C02.+K;]`^:T!`8MC``V+C?Q;TZT5!*IP0"V+K?Q"
MTP-^0)*E>06JS@`%JLT`!8K.`0^*S@$-*HW\0M/"02*+KL-`^:1Y!*K.`0&+
MK0`$JD(`#HMN_%O3K0$0BLX5`ZI/0"Z+K@`$BJT!#BKB?4"2ID$FBZW'0/FM
M`0&+Q@`-BTW\6].M%0*JT$`MBVW\0M,&?D"2HWD#JHX``ZJ-``.*S@$/BLX!
M#2I-_$+3Q4$EBZ[+0/FB>0*JS@$!BVT``JJE``Z+SOQ;TZT!$(K.%0:JKT`N
MBVX``HJM`0XJY7U`DJ1!)(NMST#YK0$!BX0`#8NM_%O3K14%JI!`+8O-_$+3
M!'Y`DJ9Y!JI.``:J30`&BLX!#XK.`0TJK?Q"T\-!(XNNTT#YI7D%JLX!`8O-
M``6J8P`.BX[\6].M`1"*SA4$JF]`+HO.``6*K0$.*N-]0)*B02*+K==`^:T!
M`8M"``V+;?Q;TZT5`ZI00"V+C?Q"TP)^0)*D>02JK@`$JJT`!(K.`0^*S@$-
M*FW\0M/&02:+KMM`^:-Y`ZK.`0&+C0`#JL8`#HM._%O3K0$0BLX5`JK/0"Z+
MC@`#BJT!#BKF?4"2I4$EBZW?0/FM`0&+I0`-B\W\6].M%0:JL$`MBTW\0M,%
M?D"2HGD"JFX``JIM``**S@$/BLX!#2K-_$+3Q$$DBZ[C0/FF>0:JS@$!BTT`
M!JJ$``Z+KOQ;TZT!$(K.%06JCT`NBTX`!HJM`0XJY'U`DJ-!(XNMYT#YK0$!
MBV,`#8N-_%O3K14$JG!`+8NM_$+3`WY`DJ5Y!:K.``6JS0`%BLX!#XK.`0TJ
MC?Q"T\)!(HNNZT#YI'D$JLX!`8NM``2J0@`.BV[\6].M`1"*SA4#JD]`+HNN
M``2*K0$.*N)]0)*F02:+K>]`^:T!`8O&``V+3?Q;TZT5`JK00"V+;?Q"TP9^
M0)*C>0.JC@`#JHT``XK.`0^*S@$-*L5!)8NN\T#YS@$!BZ4`#HO._%O3SA4&
MJJY`+HM%_$+3SWU`DJ)X`JIM``*J90`"BJT!$(JM`04JQ?Q"TZ9X!JJD022+
M10`&JJ4`#HI.``:*I0`.*J-`(XNMEUZIY^1'^:T!`8NA``&+A``-B^W]6]-C
M``&+K14/JHU`+8ND?4"2COQ;T\X5!*IN0"Z+X_U"T\5]0))O>`^JH_]`^<$`
M#\HA``U*K?Q;TR)`(HO!.IC204RY\JT5!:IC``&+0@`#BX/\0M-D>`2J0D`M
MB^,!!,I1?$"28P`.2F9`)HNC`T'Y+OY;TV,``8O&``.+SA41JJ/\0M/.0"Z+
M)OY"T]!]0))E>`6J@P`%RM%X$:IC``)*H@=!^0W^6].F`!'*0@`!BV-`+XNM
M%1"J8P`"B\8`#DH"_D+38T`MBV]\0)+$0"2+I@M!^4)X$*KM_5O3Q@`!BX0`
M!HLF`@+*K14/JL,``TJ$0"V+94`EBY)\0)*C#T'Y8P`!BTW^6].E``.+X_U"
MTZT5$JIC>`^JI4`MBT8``\JP?$"2Q@`$2J030?G&0#&+A``!BPW^6]/&``2+
M1/Y"TZT5$*J$>!*JQD`MBVT`!,JE`05*SGQ`DJ)`(HNE%T'YS?U;TZ4``8M"
M``6+!?Y"TZT5#JJE>!"J0D`MBXT`!<JF`09*47Q`DL-`(XNF&T'Y+?Y;T\8`
M`8MC``:+QOU"TZT5$:K&>`ZJ8T`MBZT`!LJB`0)*;WQ`DD1`)(NB'T'Y[?U;
MTT(``8N$``*+(OY"TZT5#ZI">!&JA$`MB\T``LJC`0-*CGQ`DF5`)8NC(T'Y
MS?U;TV,``8NE``.+X_U"TZT5#JIC>`^JI4`MBTT``\JD`01*L'Q`DH9`)HND
M)T'Y#?Y;TX0``8O&``2+Q/U"TZT5$*J$>`ZJ;@`$RL9`+8O%`05*S7Q`DJ)`
M(HNE*T'YKOU;TZ4``8M"``6+!?Y"T\X5#:JE>!"JCP`%RD)`+HOF`09*3GQ`
MDL-`(XNF+T'YQ@`!BV,`!HO&_5O3QA0.JF-`)HNF_4+3;WQ`DLUX#:JF``W*
MP@`"2N;]6]-$0"2+HC-!^<84#ZI"``&+A``"B\+]0M-">`ZJA$`FBZX!`LJ&
M?$"2PP$#2F5`)8NC-T'YSOQ;TV,``8NE``.+X_U"T\X5!JIC>`^JI4`NBTX`
M`\JP?$"2Q`$$2HU`+8ND.T'Y#_Y;TX0``8NM`02+[Q40JL3\0M.O02^+[7U`
MDH9X!JID``;*A0`%2J0_0?FN_5O3A``!BZ)`(HM"``2+SA4-J@7^0M-.0"Z+
ML'@0JL)]0)+$`!#*I4-!^8\`#TJD_4+3I0`!B^-!(XM/_%O38P`%BXUX#:KO
M%0*JK`$,"PP0`/EE0"^+#P(-RNX!#DJC?$"2Q$$FBZ9'0?G&``&+A@`&BV3\
M6].$%`.JA``&"T;\0M,(`00+PG@"JF;\0M-+``L+PW@#JJ8!`LK%``5*IDM!
M^6H`"@O!``&+I4`PBZ4``8N!_%O3"BP!J2$4!*HA``4+*0`)"PD@`*FA3T'Y
MX`!`^2```,I```"TT/K_E_U[P:C_0PJ1P`-?UOU[O*G]`P"1\U,!J10`@-+U
M6P*I]V,#J>```+2B``#0%`"`TD+@1_E7`$#YX@,`JA<!`+7@`Q2J\U-!J?5;
M0JGW8T.I_7O$J,`#7]9"!`"10P!`.7_T`'%D&$!Z@?__5$(``$OX`P&J]@,`
MJO4#%ZI3?$"3M`)`^?3]_[3B`Q.JX0,6JN`#%*H.^O^70`$`-8!J<S@?]`!Q
MX0``5+4"%\MS!@"1E`(3B[7^0Y,5`P"YX?__%[4B`)'O__\7_7N]J?T#`)'S
M"P#YLP``T'/F1_EA`D#YH1<`^0$`@-*ADP"1R/__EZ(70/EA`D#Y00`!RD$`
M`+2/^O^7\PM`^?U[PZC``U_6_7N\J?T#`)'U6P*I]0,`JJ```-#S4P&IM```
MT/,#`*JVTP"1`>1'^93B1_DB`$#YHA\`^0(`@-+A`Q:JX`,5JJ___Y?@``"U
M8.9'^:$?0/D``$#Y(```RD`!`+1T^O^7H#>`N8$"0/D@#`"+`01`^0$``/DA
M_O^T`"``D?S__Q?S4T&I]5M"J?U[Q*C``U_6_7NZJ?T#`)'S4P&IM```T/5;
M`JGU`P&J]V,#J?8#`*KY:P2I@.9'^0$`0/FA+P#Y`0"`TJ`"0#D?]`!QM1:5
MFN`#%:I2^O^7]P,`JJ%3`9'@`Q:JAO__ER`"`+3S`P"J2_K_E_\"`.MH!@!4
M``"`TJ%J8#AA:B`X``0`D:'__S4``(!2E.9'^:(O0/F!`D#Y00`!RL$)`+1!
M^O^7LP``T&#B1_D9`$#Y``"`TO@#`"H`!`"1(0\`BR&`7_B!__^UH0``\``+
M`!$BZ$"Y(@$`-`%\?9/@`QFJ3?G_EV'B1_D@``#YP`$`M0``@!+F__\7`'Q]
MDR(`@%(BZ`"YA/G_E_H#`*H@__^T`G]]D^$#&:J#^?^78.)'^1H``/ESXD?Y
M`']`DP`$`)%A`D#Y/W@@^+A7`+GA`Q:J(`!`.1_T`'$$&$!Z`00`5+,``-"X
M5X"Y(0`6R^`*`)%SXD?Y`,`ABQCS?=-Y`D#Y:?G_ER!K./C`^_^T8`)`^:%7
M@+D#>&'X``"`TL%J8#AB``"+/_0`<6%H(#@D&$!Z``0`D4'__U2@!X!20```
M.0``@-)#``"+H6I@.``$`)%A!``Y@?__-;#__Q<A!`"1W/__%_-30:GU6T*I
M]V-#J?EK1*G]>\:HP`-?UOU[LJG]`P"1\U,!J;0``-#U6P*I]V,#J?EK!*F!
MYD?Y(@!`^:)O`/D"`(#28`(`M`$`0#GU`P"J`0(`-._X_Y?W`P"JH`$`M!@`
M`+`9``"P&)<WD3F3-Y&Z8P&1X`,7JAKY_Y=@`0"UX`,7JD/Y_Y?@`Q6JG?G_
MEY3F1_FA;T#Y@`)`^2```,I@!0"TR_G_EQ-,`)'A`QBJX`,3J@?Y_Y?@_?\T
MX0,9JN`#$ZH#^?^78/W_-.`#%:J\^?^7]@,`JN`#$ZJY^?^7```6"P`(`!$`
M?$"3%?G_E_8#`*H!``"PXP,3JN(#%:HAG#>1G_G_E^$#&JK@`Q:JC/G_EQ\$
M`#%``0!4H&M`N0`,%!(?$$!QP0``5.`#%JJZ__^7X`,6JG[Y_Y?.__\7X`,6
MJOOX_Y?[__\7\U-!J?5;0JGW8T.I^6M$J?U[SJC``U_6_7N^J?T#`)'S4P&I
MLP``T/0#`*ISVD?Y8`)`N7SY_Y<!X`>1X`,4JOWX_Y>@```T``"`4O-30:G]
M>\*HP`-?UF`"0+ER^?^7``A"N0`,%!(?$$!QX0``5.`#%*I!`(!2I_C_EQ\`
M`''@%Y\:\O__%V`"0+EF^?^7``A"N0`,%!(?*$!Q8?W_5/3__Q>@``#0_7N_
MJ?T#`)$`V$?Y``!`N5OY_Y>B``#0`P``L`$``+!CX#:1_7O!J"&T-Y%"]$?Y
M2_G_%_U[OJG]`P"1\PL`^;,``-!SVD?Y8`)`N4SY_Y?K__^78`)`N4GY_Y?S
M"T#Y!```T`(``+"$[`&1`0``L/U[PJCC`P2J0M`GD2$D.)$%`(!2@OC_%_\+
M0-'_@P#1_7N]J?T#`)'U6P*IM@``T/-3`:FTXP"1P.9'^0$`0/FA)Q#Y`0"`
MTH7X_Y?C`P`J!```L`(``+"$>#B10H@XD>`#%*HA`(+2:?C_EQ\$`#$A`0!4
M`P"`TL'F1_G@`P.JHB=0^2$`0/E!``'*(04`M#?Y_Y<!?$"3/P1`\4D``%0`
M?2#4@/[_-P`(@M("`(+2LP,`B^`#%*KA`Q.JR/C_E_4#`*J`_?\W``0`$0!\
M0).#^/^7XP,`JN#\_[0?`!/KM'Y`DX(``%0``!2+?P(`ZX/]_U1_`!/KB0``
M5&`"%(M_``#KX_S_5"``@E*_`@!KC/S_5.`#`ZKB`Q2JX0,3J@/Y_Y?C`P"J
M'V@T.-/__Q?S4T&I]5M"J?U[PZC_"T"1_X,`D<`#7]:T__\7_P=`T?]#`-']
M>[JI_0,`D?-3`:FT``#0]5L"J?4#`*KY:P2I\P,!JO=C`ZF`YD?Y^RL`^0$`
M0/FA-PCY`0"`T@```+``N#B16?[_E_H#`*K@`Q6JX06`4GKX_Y>``0"T````
ML.$#%:H`W#B1AO[_EY3F1_G@`Q6JHC=(^8$"0/E!``'*`0H`M.;X_Y?@`Q6J
M%@``L!<``+`9``"P]Y8WD3D;.9';^/^7^`,`*L$2.9'@`Q.J&`<`$;[X_Y?S
M`P"J$_W_M&`"0#D?``!Q\P*3FEH!`+3A`Q.JX`,:JA'X_Y?````UP1(YD0``
M@-*Q^/^7\P,`JO/__Q?@`Q.JQ?C_EV'"((LA\%\X/[P`<2`"`%0``P`+'_P_
M<4SZ_U2[HP&1`@``L.4#%:KD`QFJXP,3JD*8/)'@`QNJ`0""TN'W_Y<`!``1
M'P1`<:D``%0`?2#4``0`47_*(#CJ__\7LP``T'/:1_E@`D"YEOC_EP'@!Y'@
M`QNJA_C_EV#[_S5@`D"YD/C_EP`(0KD`#!02'R!`<:'Z_U3@`QNJ(0"`4L7W
M_Y<@^O\U````L.$#&ZH`W#B1-?[_E^`#&ZH.^/^7]0,`JJS__Q?S4T&I]5M"
MJ?=C0ZGY:T2I^RM`^?U[QJC_!T"1_T,`D<`#7]8!!`"1(O!?.$(``#7``U_6
M7[P`<0`0@9HA!`"1^O__%\`'`+3]>[ZI_0,`D?-3`:GS`P"J%`!`.=0``#4`
M``"P`)0WD?-30:G]>\*H[_?_%W;X_Y<"!`#18@("BW\"`NNB`@!40`!`.1^\
M`'&@`0!40`!`.1^\`'&!`0!40@0`T7\"`NMC`@!40@`3RT`(`)$?!$#Q:0(`
M5```@-(<```40@0`T>[__Q="!`#1?P("ZP/^_U1_`@+K(?[_5)^^`''@^_]4
M````L``8.9'>__\70`!`.1^\`'$@_?]4Z___%T($`)%?!$#Q20``5`!](-2T
M``#PX0,3JI2B`Y&4(@"1X`,4JNWW_Y?@`Q2J\U-!J?U[PJC``U_6````L`"4
M-Y'+__\7_7NYJ?T#`)'S4P&ILP``T/5;`JD6``"P]QL`^1<``+!@YD?Y%```
ML!4``+`!`$#YH3<`^0$`@-(```"P`.`VD;4^.I$`*`"1`@Q`J:(/!*D"#$&I
M`$!`>:(/!:F@PP!Y````L``@.9&@_?^7````L`!$.9&=_?^7````L`!D.9&:
M_?^7````L`"(.9&7_?^7P*8YD97]_Y<```"P`.0YD9+]_Y?@NCB1D/W_EX`6
M.I&._?^7X`,5JHS]_Y<```"P`&0ZD8G]_Y<```"P`-PXD8;]_Y<```"P`(PZ
MD8/]_Y<```"P`+`ZD8#]_Y<```"P`-PZD6O]_Y>```"TX0,`JN`#%:J=_?^7
M````L``@.Y%D_?^7H```M.$#`*H```"P`&@[D97]_Y<```"P`)0[D5S]_Y?`
M`0"TX0,`JN"Z.)&._?^7`0``L,"F.9$A1#R1BOW_EW/F1_FA-T#Y8`)`^2``
M`,H@`@"TZ_?_EP```+``U#N12_W_E^$#`*H@`0"U`0``L*!'`9$A&#R10@&`
MTK4#`9%$]_^78/W_-:%N`)&`%CJ1Y___%_-30:GU6T*I]QM`^?U[QZC``U_6
M_7N^J?T#`)'S"P#YLP``\&`*0+D?!``QH0$`5````+``%#J1,/W_EP$`@%+@
M``"T``!`.1\``''A!Y\:'\``<>`'GQHA```*80H`N6`*0+GS"T#Y_7O"J,`#
M7];]>[^I_0,`D<'W_Y=,]_^7X0,`J@``@-)!``"T(`!`^?U[P:C``U_6_7NV
MJ0('@-+]`P"1^RL`^;L``-#U6P*I]0,`JOEK!*FY@P&1]V,#J18``+!@YT?Y
M%P``L/-3`:D:`(#2UA(YD?>:/)$!`$#YH4\`^0$`@-+@`QFJH0``T"$@`)$A
M(`"1C??_ES-K>OCS``"U8.='^:%/0/D``$#Y(```R@`$`+25]_^7X`,3JO;\
M_Y?T`P"J8```M`$`0#G!```UX0,5JN`#$ZHE_?^76B,`D>[__Q?A`Q6J!/?_
MEX#__[7@`Q6J@??_E_@#`*K@`Q2J?O?_EP`#`(L`"`"1V_;_E_@#`*KA`Q>J
MY`,4JN,#%JKB`Q6J9??_E^$#&*KJ__\7\U-!J?5;0JGW8T.I^6M$J?LK0/G]
M>\JHP`-?UO\C0-$"-9#2_T,%T?U[NJG]`P"1^6L$J;H``+#U6P*I]@,`JO-3
M`:FA`P*+]V,#J;4#`I'[<P6IM,,"D4#G1_FW8P*1&P``D`(`0/DB``#Y`@"`
MTJ```-``(`"1`2A`^0(,1*FA"@#Y`6`!D:(.`*D`(`*1(@Q`J8(.`*DB#$&I
M@@X!J2(,0JF"#@*I`@Q`J0`(0/GB#@"IX`H`^6"[.)&J_/^7NS\`^2`"`+0!
M`$`Y\P,`JL$!`#2,__^7X`,3JK/V_Y?T`P"J6N='^0$UD-*A`P&+X`,4JB(`
M0/E!`T#Y00`!RD%``+0U]_^7=?__E_,#`*H``@"U&`"`T@!K=_B```"U$P``
MD'-./)$*```4COS_EQ,`@-*@``"T`0!`.6$``#2:]O^7\P,`JA@C`)%S_O^T
MX`,3JA@``)`8:SR1&_?_EP#X?],`!`"1>/;_E_D#`*KW`P"J8@)`.0((`#43
M`(#2>&IT^)@!`+3@`QBJ=OS_E_<#`*K@!P"T`0!`.:$'`#1S_?^78`<`-.`#
M%ZI_]O^7^`,`JA0`@-*X``"UDVIU^',``+1@`D`Y@`8`->`#&*H5``"0_?;_
ME_,#`*K@`QFJ^O;_EQ,`$PMS$A`1<WY`D^`#$ZI5]O^7]P,`J@0``)`!``"0
MY0,9JH1\/)&C&CF1X@,8JB&0/)'<]O^7X`,7J@$X@%+!]O^7'P0`,6$$`%2Z
M]O^7``!`N1]$`''@`P!4H```L-0"0/D`O$?Y$P!`^;+V_Y<!``"0!`!`N>,#
M%ZKB`Q2J(;0\D>`#$ZJ/]O^7%`"`TIS__Q?@`Q>JX0,8JG,&`)'W"@"1P/;_
ME[K__Q=S(@"1N___%^`#$ZHT_?^7@```-.`#$ZI`]O^7^`,`JI0B`)'!__\7
MM```L)3:1_F``D"YK?;_EP'@!Y'@`Q>J+O;_E_@#`"I@,``U@`)`N:;V_Y<`
M"$*Y``P4$A\00'&A+P!4@`)`N:#V_Y<9$$*YNO;_ES\#`&OA+@!4@`)`N9KV
M_Y<`"$*Y`"``$A\`!W$A+@!4X`,3J@CV_Y?T`P"J````L`"0`I$+_/^7``$`
MM-,"0/D9]O^7X0,`JN`#$ZJ:_?^7\P,`JD```+73`D#YX`,3JIGV_Y<?#`!Q
M^0,`JHT#`%0`?$"3`0``D``0`-$AH#V18`(`B]3U_Y>@`@`U/Q,`<<```%0Y
M$P!1><(YBR#S7S@?O`!QP0$`5-8&0/F6`0"TX`,6JH3V_Y<?#`#Q"0$`5``0
M`-$!``"0(;0]D<`"`(O!]?^7'P``<7,2EIJH_O^7(",`->`#$ZH!`(!2\O7_
ME_D#`"J`(@`T0@"`4B$"@)*VHP:1K/7_E^$#%JK@`QDJP@"`TC3V_Y>@HT8Y
M0`4`-:"G1CD?#`%QX00`5*"K1CD?!`%Q@00`5*"O1CD?#`%Q(00`5*"S1CD?
M(`%QP0,`5*"W1CD?%`%Q80,`5.`#&2I"`(!2(0>`DI/U_Y?A`Q:JX`,9*B(%
M@-(;]O^7!0``L.0#%JJE[`&1`0``D*,:.9'B`Q>J(<@]D>`#%*HZ]O^7X`,7
MJB3V_Y>@/T#YX0,4J@"X.)'A^_^7X`,4JI'^_Y<(__\7X`,9*@(`@%(!`(#2
MN(,#D1SC`)%W]?^7O_\0J2!@A-*_6P&YH.BL\J!S`/D@<972H/F]\J!W`/G`
MGYO20!>S\J![`/G`CHK20`:B\J!_`/D`/IS20'JX\J"#`/D`XP&1H#L`^>$#
M%JK@`QDJ`@"0TNSU_Y<?``!QY0,`JO,#`"IL#`!4X`,9*M[U_Y>SVU"IH6,$
MD>,/@!)@(D/3`@0`$0!\0)-?X`!Q(V@@.$!\0).M%0!4`0B`4AGC`)$B``)+
M(`,`BP$`@%)"?$"38?7_E^`#&*KS]O^7X`,9J@('@-(!`(!26_7_E[9/!3G`
M_EC3LU\%.;F#!9&@0P4YP/Y0TZ!'!3G`_DC3%@``D*!+!3E@_EC3UFH\D:!3
M!3E@_E#3H%<%.6#^2-,3`(#2H%L%.>`#&*JXXP61VO;_EZ!S0/F@CP4Y`?Q8
MTZ&#!3D!_%#3H8<%.0'\2-.@=T#YH8L%.:"?!3D!_%C3H9,%.0'\4-.AEP4Y
M`?Q(TZ![0/FAFP4YH*\%.0'\6-.AHP4Y`?Q0TZ&G!3D!_$C3H']`^:&K!3F@
MOP4Y`?Q8TZ&S!3D!_%#3H;<%.0'\2-.@@T#YH;L%.:#/!3D!_%C3H<,%.0'\
M4-.AQP4Y`?Q(TZ'+!3EB:GDX``<3B^$#%JIS!@"1M?7_EW]2`/%!__]4!0``
ML+^#!CFE[`&1Y`,8JF___Q>AAT#YH'Q`DR(,``L_``+KB0``5*&+0/DA!`"1
MH8L`^:&+0/D@=$"+HH,0J:!;0;E@!``T$PB`4G,"`$N`PR"+OP`3:[/0DQH?
M`!;K>WY`DX(``%0!`!N+WP(!Z\,``%0?`!;KJ0``5,$"&XL?``'K0@``5`!]
M(-1_(T#QI3<`^:C__U3B`QNJX0,6JH[U_Y>@6T&YI3=`^6`"``L?``%QH%L!
MN:'M_U2S`!-+VP(;B^`#&*IX]O^7`@``%/L#%JI__@!Q;`(`5'\#'.MB?D"3
MB0``5(`#`HM_`P#KP_S_5'\#'.N"``!48`,"BY\#`.LC_/]47R`!\>C[_U3A
M`QNJX`,<JG#U_Y>S6P&Y4___%Z`[0/F?`QOK`#!;^LCZ_U1_`QSK8P,!D6(`
M`%2?`P/K(_K_5.$#&ZK@`QRJ`@B`TJ,W`/ES`@%17_7_EZ,W0/G[`P.JU___
M%P$'@%(#XP"1(@`"2V```(L!`(!20GQ`DUK__Q<!``"0````D"%$/)$`%#J1
M$P``L+4:.9%S[@&1%@``D/7Z_Y?6/CZ1EO3_E^0#`"H!``"0Y0,3JN,#%:KB
M`Q>J(00^D>`#%*H^]?^7X`,4J@$X@%(C]?^7'P0`,0'@_U0<]?^7``!`N1]$
M`'&!W_]4A/3_EQ@'`!'D`P`JY@,3JN4#&"KC`Q6JX@,7JN$#%JK@`Q2J*_7_
ME^W__Q>@``"P`0``D,("0/GC`Q>J(8`^D0"\1_D``$#YZO3_EUO^_Q?S4T&I
M]5M"J?=C0ZGY:T2I^W-%J?U[QJC_(T"1_T,%D<`#7];]>[JI_0,`D?-3`:FS
M``"P]5L"J?=C`ZETVD?Y^6L$J?MS!:F``D"Y"?7_E_4#`*J``D"Y!O7_EP#`
M0CF@Q@(Y````D`"D.9%\^O^7P```M`$`0#D_Q`!Q80``5``$0#E````TS?S_
MEW7:1_FT``#PH`)`N?;T_Y<!``"08P&`4B',/Y$B`(!2C?3_ER`$`+5VVD?Y
MP`)`N>WT_Y<!``"08P"`4B'@/Y$B`(!2A/3_E_4#`*K@"0"U=MI'^<`"0+GC
M]/^7`0``D&,`@%(AU#J1(@"`4GKT_Y?U`P"J(`P`M````)``W#B15/K_E_<#
M`*H@"@"TP`)`N=7T_Y>A"D#YX@,7JB$`0/EU]/^750``%``(0/D;@(!2FJ('
MD18`@%(;!*!R&11`^4"#4+C7!@`1_P(`:RH!`%2@`D"YQ/3_E\)^0)/A`QFJ
M`P"`4B3T_Y?X`P"J0`(`M8"B!Y$!@%"X(00`4=\"`6M!^?]4=]I'^?4#`*HV
M`(!2H()0N-\"`&N*^/]4X`)`N=8&`!&P]/^7X0,9JMKS_Y?X__\7`0!`^4`#
M4?@<V'?X(`Q`N0``&PH?`!!Q`0$`5"`(0/GA`P"JX`,<JOKS_Y>`_/\U]@,7
M*M;__Q>@`D"YG?3_EP$#0/E#`(!2`@"`TJGT_Y?T__\7P`)`N9;T_Y>A"D#Y
M`@``D$+H/Y$A`$#Y-?3_EZ`*0/D``$#Y``Q`N0#UMS;``D"YB_3_EZ$*0/DA
M`$#Y]//_EZ+__Q=)^_^7]P,`JL`"0+GW!`"T@O3_EZ$*0/GB`Q>J(0!`^2+T
M_Y?@`Q>J;/3_EW/:1_E@`D"Y>?3_E_4#`*I@`D"Y=O3_EP$``)`B`(!2(?P_
MD:KS_Y?A`P"J`@``L.`#%:I"4`"1$?3_EV`"0+F3H@>1:O3_EQ_$`CD```"0
M`+@XD>'Y_Y=@@A'XP`$`M6`"4?@+_?^78((1^$`!`+4```"P`&@`D:7S_Y=<
M]/^7@:('D2(`4?BA"D#Y0@!`^87__Q>4H@>1`3B`4H""4?@_]/^7`00`$3\$
M`'$$B%%ZX```5($*<:GC`P`J````L`#L`)$A`$#YD?/_E_-30:GU6T*I]V-#
MJ?EK1*G[<T6I_7O&J,`#7];]>[ZI_0,`D?-3`:GS`P"JS_O_E\;[_Y?T`P"J
M?/S_EQ\``'%D&D#ZH`$`5&`"0#E@`0`T`0``D.`#%*HA?#R1Q?/_EY\"`.NA
M``!4X`,3JO-30:G]>\*H5?K_%_-30:G]>\*HP`-?UOU[OZG]`P"1_7O!J,`#
M7]8`````<&5R;'AS:2YC`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@```N+@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT
M97)N86QS.CI005(Z.D)/3U0`97AE`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!
M4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),
M24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?
M1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,3T)!
M3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!365-414T`
M)3`R>`!P87(M`"5S)7,E<R5S`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`<&%R;``N<&%R`"5S
M)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P`E
M<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@
M<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*`$%21U8`&`!P
M97)L`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#,V`%5N86)L92!T;R!C<F5A
M=&4@8V%C:&4@9&ER96-T;W)Y`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A
M8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`+64`+2T`
M55-%4@!54T523D%-10!414U01$E2`%1-4``O=&UP`$Q)0E!!5$@`1%E,1%],
M24)205)97U!!5$@`4TA,24)?4$%42`!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L
M("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%
M04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN
M9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P
M=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP
M*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N
M92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U0
M3$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P
M+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M
M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P
M87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X
M("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM
M;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N
M86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E
M;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T
M;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]
M"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9)
M;G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*
M:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=6
M7S!]("D@>PI`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N
M+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%27T%21U9?,'T[
M"GT*96QS92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D14Y6>R1??2!I
M9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>
M35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O
M7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM
M("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P*
M*3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A
M<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@
M<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN
M;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*
M;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD
M;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@
M+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA
M;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T
M.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE
M<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN
M4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D
M<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]
M"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*
M<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E
M:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@
M7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@
M)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I
M;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE
M*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL
M;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-
M4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X
M="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*
M?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A
M=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC
M<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L
M("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M
M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI
M<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@
M;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D
M*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@
M9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D
M9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@
M)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F:6QE
M;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB=69]*3L*;W!E;B!M>2`D
M9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA
M;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O
M='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S
M="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N
M9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%0
M4%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y
M('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*
M:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N
M<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T
M;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S
M:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=6
M6S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!0
M7U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L
M(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!
M4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0[
M"FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E
M<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U
M;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@
M/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*
M96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@
M9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E
M<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF
M("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%2
M7U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T
M*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G
M/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN
M;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")2
M96%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D
M>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I
M*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ
M+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO
M8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\
M)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@
M(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<
M,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL
M93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@
M;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?
M<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY
M("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@
M*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE
M>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D
M;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S
M970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@
M<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H
M*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D
M97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"
M4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F
M:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S
M+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[
M;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I
M;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I
M;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI
M('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N
M*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA
M<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2![
M"FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@
M*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L
M("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A
M;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I
M(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B
M(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z
M("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL
M92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@
M1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A
M(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)
M3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]
M?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U
M=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*
M)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ
M8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H
M<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N
M=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z
M:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*
M:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI
M6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I
M.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I
M*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D
M9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T
M(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG
M=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M
M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2
M+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*
M?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G
M;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G
M*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I
M92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%2
M7U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U
M=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*
M)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO
M9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]
M"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@
M(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M
M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@
M70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]
M"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&
M:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E
M<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U
M;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS
M=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN
M84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q
M=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L
M.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA
M;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI
M8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W
M9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!3
M8V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z
M.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T
M=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z
M.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?
M<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U
M<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!0
M05)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<
M7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@
M86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D
M<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN
M960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*
M)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN
M960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S
M97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE3
M5$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@
M(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R
M;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,
M14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*
M;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L
M(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#
M04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L
M(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M
M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z
M.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T
M.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U
M+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I
M;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C
M='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H
M)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D
M8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L
M<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@
M)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L
M("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE
M(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F
M=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D
M:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*
M<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@
M)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L
M("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F
M=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%
M3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H
M+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII
M9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM0
M05)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]
M"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG
M+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG
M>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<
M421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O
M9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92![
M"B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G
M;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D
M(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H
M*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@
M8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_
M7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET
M7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*
M<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]
M"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]]
M.PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.
M5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES
M=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@
M(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[
M4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@
M*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@
M/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD
M14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]
M*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H
M)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT
M(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP
M=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD
M7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET
M96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA
M9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I
M;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L
M.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H
M(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O
M("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@
M)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?
M7T524D]2.PHQ.PI?7T5.1%]?"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````.`A````````>"$```````````````````$``````````0`````````!
M`````````/4"````````#P````````"G`P````````P`````````J!H`````
M```-`````````*1-````````&0````````!HFP$``````!L`````````"```
M```````:`````````'";`0``````'``````````(`````````/7^_V\`````
MZ`$````````%`````````+@,````````!@````````#(`@````````H`````
M````I`0````````+`````````!@`````````%0````````````````````,`
M````````8)T!```````"`````````-`%````````%``````````'````````
M`!<`````````V!0````````'`````````&`1````````"`````````!X`P``
M``````D`````````&``````````8````````````````````^___;P`````!
M```(`````/G__V\`````%@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````,`:````````
MP!H```````#`&@```````,`:````````P!H```````#`&@```````,`:````
M````P!H```````#`&@```````,`:````````P!H```````#`&@```````,`:
M````````P!H```````#`&@```````,`:````````P!H```````#`&@``````
M`,`:````````P!H```````#`&@```````,`:````````P!H```````#`&@``
M`````,`:````````P!H```````#`&@```````,`:````````P!H```````#`
M&@```````,`:````````P!H```````#`&@```````,`:````````P!H`````
M``#`&@```````,`:````````P!H```````#`&@```````,`:````````P!H`
M``````#`&@```````,`:````````P!H```````#`&@```````,`:````````
MP!H```````#`&@```````,`:````````P!H```````#`&@```````,`:````
M````P!H```````#`&@```````,`:````````P!H```````#`&@```````,`:
M````````P!H```````#`&@```````,`:````````P!H```````"`FP$`````
M`,`>`````````````````````````````*1-````````````````````````
M````````````````J!H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@`0``````_____P````"K4````````*%0````````KE``
M``````"D4````````*E0````````NU```````````````````)Q0````````
MY4T``````````````````-I.````````TTX```````"04````````/!.````
M````F%```````````````````()0````````AU```````````````````,90
M````````1T-#.B`H06QP:6YE(#8N,RXP*2`V+C,N,```+G-H<W1R=&%B`"YI
M;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L82YD>6X`+G)E
M;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE`"YI
M;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T
M80`N8G-S`"YC;VUM96YT````````````````````````````````````````
M``````````````````````````````````````````````````L````!````
M`@````````#(`0```````,@!````````&@````````````````````$`````
M```````````````3````]O__;P(`````````Z`$```````#H`0```````-P`
M`````````P`````````(````````````````````'0````L````"````````
M`,@"````````R`(```````#P"0````````0````#````"``````````8````
M`````"4````#`````@````````"X#````````+@,````````I`0`````````
M``````````$````````````````````M````!`````(`````````8!$`````
M``!@$0```````'@#`````````P`````````(`````````!@`````````-P``
M``0```!"`````````-@4````````V!0```````#0!0````````,````1````
M"``````````8`````````$$````!````!@````````"H&@```````*@:````
M````$`````````````````````0````````````````````\`````0````8`
M````````P!H```````#`&@`````````$```````````````````0````````
M`!``````````1P````$````&`````````,`>````````P!X```````#D+@``
M````````````````!````````````````````$T````!````!@````````"D
M30```````*1-````````$`````````````````````0`````````````````
M``!3`````0````(`````````N$T```````"X30````````I`````````````
M```````(````````````````````6P````$````"`````````,2-````````
MQ(T````````$````````````````````!````````````````````&4````.
M`````P````````!HFP$``````&B;````````"`````````````````````@`
M````````"`````````!Q````#P````,`````````<)L!``````!PFP``````
M``@````````````````````(``````````@`````````?0````$````#````
M`````'B;`0``````>)L````````(````````````````````"```````````
M`````````((````&`````P````````"`FP$``````(";````````X`$`````
M```$``````````@`````````$`````````"+`````0````,`````````8)T!
M``````!@G0```````*`"```````````````````(``````````@`````````
MD`````$````#``````````"@`0```````*````````"P````````````````
M````"````````````````````)8````(`````P````````"PH`$``````+"@
M````````8!````````````````````@```````````````````";`````0``
M`#````````````````````"PH````````!H````````````````````!````
M``````$``````````0````,`````````````````````````RJ````````"D
?`````````````````````0``````````````````````
